aboutsummaryrefslogtreecommitdiff
path: root/src/audio_parser.h
diff options
context:
space:
mode:
authorMax Kellermann <max@duempel.org>2009-10-21 22:22:23 +0200
committerMax Kellermann <max@duempel.org>2009-10-21 22:22:23 +0200
commit643650dba75becfe572c1b334d1276a1b3f66d41 (patch)
tree5617dd0c2b0890de13a655524181acbb85cad7d0 /src/audio_parser.h
parent8cb6854da4c7966cf45f701dde35ee72fc931e64 (diff)
audio_parser: renamed parameter "error" to "error_r"
It's a double pointer.
Diffstat (limited to 'src/audio_parser.h')
-rw-r--r--src/audio_parser.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/src/audio_parser.h b/src/audio_parser.h
index 30a92745..1d821eaf 100644
--- a/src/audio_parser.h
+++ b/src/audio_parser.h
@@ -37,11 +37,12 @@ struct audio_format;
*
* @param dest the destination #audio_format struct
* @param src the input string
* @param error location to store the error occuring, or NULL to
* ignore errors
* @return true on success
*/
bool
-audio_format_parse(struct audio_format *dest, const char *src, GError **error);
+audio_format_parse(struct audio_format *dest, const char *src,
+ GError **error_r);
#endif
@@ -37,11 +37,12 @@ struct audio_format;
* @param dest the destination #audio_format struct
* @param src the input string
- * @param error location to store the error occuring, or NULL to
+ * @param error_r location to store the error occuring, or NULL to
* ignore errors
* @return true on success